#########################################################################
#            .bashrc: Personal initialisation file for Bash             #
#########################################################################

# This file is executed by interactive shells (ie, shells for which you
# are able to provide keyboard input).  It is the best place to put shell
# aliases, etc.
#
# [JNZ] Modified 16-Nov-2005
#
# Written by John Zaitseff and released into the public domain.


# Variable settings for your convenience

export LANG=en_AU.UTF-8				# We are in Australia
export LC_ALL=en_AU.UTF-8
export TIME_STYLE=$'+%b %e  %Y\n%b %e %H:%M'	# As used by ls(1)
export EDITOR=emacs				# Everyone's favourite editor

# Useful aliases, defined whether or not this shell is interactive

alias cls=clear
alias ls="ls -v"
alias l.="ls -A"
alias dir="ls -laF"
alias lock="clear; vlock -a; clear"
alias e="emacs -nw"


# Run the following only if this shell is interactive

if [ "$PS1" ]; then

    export IGNOREEOF=5			# Disallow accidental Ctrl-D
    export HISTIGNORE="&: +.*"		# Forget commands starting with space
    unset HISTFILE			# Don't save commands to history file

    # Allow the Debian Chroot Compilation Environment to modify the prompt
    if [ -z "$debian_chroot" ]; then
	PS1h="\h"
    else
	PS1h="($debian_chroot)"
    fi

    # Set options, depending on terminal type
    if [ -z "$TERM" -o "$TERM" = "dumb" ]; then
        # Not a very smart terminal
	PS1="\u@$PS1h:\w \\\$ "
    else
        # Assume a smart VT100-based terminal with colour

	# Make sure the terminal is in UTF-8 mode.  This is a hack!
	/bin/echo -n -e '\033%G'

	# Make ls(1) use colour in its listings
        if [ -x /usr/bin/dircolors ]; then
            alias ls="ls -v --color=auto"
            eval $(/usr/bin/dircolors --sh)
        fi

	# Set the terminal prompt
        if [ $(id -u) -ne 0 ]; then
	    PS1="\[\e[42;30m\]\u@$PS1h\[\e[37m\]:\[\e[30m\]\w\[\e[0m\] \\\$ "
        else
            # Root user gets a nice RED prompt!
	    PS1="\[\e[41;37;1m\]\u@$PS1h\[\e[30m\]:\[\e[37m\]\w\[\e[0m\] \\\$ "
        fi
    fi
fi
